.. SpiPy documentation master file, created by
   sphinx-quickstart on Mon Apr 22 14:37:52 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SpiPy's documentation!
=================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   Readme <README.md>
   Getting Started <getting_started.md>
   Examples <examples.md>
   Reference <reference>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`



